@@ -7,13 +7,15 @@ fn main() {
     theme.apply();
     let mut win = window::Window::default().with_size(400, 300);
     let mut choice = menu::Choice::new(100, 100, 200, 30, None);
-    choice.add_choice("Classic|Aero|Metro|Aqua|Greybird|Blue|HighContrast|Dark");
+    choice.add_choice("Classic|Aero|Metro|Aqua|Greybird|Blue|HighContrast|Dark|Fluent");
     choice.set_value(3);
     choice.set_frame(widget_themes::OS_PANEL_THIN_UP_BOX);
-    let mut check = button::CheckButton::new(160, 150, 80, 30, "Check");
+    let mut check = button::CheckButton::new(160, 150, 80, 30, "  Check");
     check.set_value(true);
-    let mut round = button::RoundButton::new(160, 180, 80, 30, "Round");
+    check.set_frame(enums::FrameType::FlatBox);
+    let mut round = button::RoundButton::new(160, 180, 80, 30, "  Round");
     round.set_value(true);
+    round.set_frame(enums::FrameType::FlatBox);
     let mut btn = button::Button::new(160, 220, 80, 30, "Hello");
     btn.set_frame(widget_themes::OS_DEFAULT_BUTTON_UP_BOX);
     win.end();
@@ -28,6 +30,7 @@ fn main() {
             5 => WidgetTheme::new(ThemeType::Blue),
             6 => WidgetTheme::new(ThemeType::HighContrast),
             7 => WidgetTheme::new(ThemeType::Dark),
+            8 => WidgetTheme::new(ThemeType::Fluent),
             _ => WidgetTheme::new(ThemeType::Classic),
         };
         theme.apply();
